<?php

/**
 * @filesource topspin.admin.inc
 * 
 * TopSpin module admin settings.
 */
 
/**
 * Return the TopSpin global settings form.
 */
function topspin_admin_settings_form($form, &$form_state, $id) {
  $form = array();
  switch ($id) {
    case 'general':
      $form = topspin_admin_settings_form_storage('general');
      break;
  }
  
  return system_settings_form($form);
}

/**
 * Helper function to store individual forms for multistep wizard.
 *
 * @param array $form_state
 * @return array
 */
function topspin_admin_settings_form_storage($id) {
  $forms = array();
  
  // Get all offers.
  $all_result = topspin_request('offers');
  $all_artists = array();
  
  // If the response from topspin is FALSE (ie not set up)
  if ($all_result !== FALSE) {
    if ($all_result->offers) {
      foreach ($all_result->offers as $index => $offer) {
        if (!isset($all_artists[$offer->artist_id])) {
          $all_artists[$offer->artist_id] = array();
        }
        $all_artists[$offer->artist_id][] = $offer;
      }
    }
    
    // Get artist specific offers.
    $params = array();
    $artist_id = variable_get('topspin_api_artist_id', NULL);
    if (!empty($artist_id)) {
      $params['artist_id'] = $artist_id;
    }
    
    $result = topspin_request('offers', $params);
    
    $artists = array();
    if ($result->offers) {
      foreach ($result->offers as $index => $offer) {
        if (!isset($artists[$offer->artist_id])) {
          $artists[$offer->artist_id] = array();
        }
        $artists[$offer->artist_id][] = $offer;
      }
    }
  }
  
  /**
   * Display the requested form (in D6 there are options for this,
   * for D7 currently just 'general')
   */
  if ($id == 'general') {
    $forms['general']['topspin_api_key'] = array(
      '#type' => 'textfield',
      '#title' => t('Key'),
      '#description' => t('Please enter your Topspin store API key.'),
      '#required' => TRUE,
      '#default_value' => variable_get('topspin_api_key', ''),
    );
    $forms['general']['topspin_api_user'] = array(
      '#type' => 'textfield',
      '#title' => t('User'),
      '#description' => t('Please enter your Topspin store username.'),
      '#required' => TRUE,
      '#default_value' => variable_get('topspin_api_user', ''),
    );
    $artist_options = array('' => t('All artists'));
    // If the account hasn't been set up or there just are no artists
    if (!empty($all_artists)) {
      foreach (array_keys($all_artists) as $artist_id) {
        $artist_options[$artist_id] = $all_artists[$artist_id][0]->artist_name;
      }
        
      $forms['general']['topspin_api_artist_id'] = array(
        '#type' => 'radios',
        '#title' => t('Choose the artist to display offers from'),
        '#description' => t("If your Topspin account is associated with more than one artist, you can choose to display all offers from all artists, or select a specific artist to display offers from."),
        '#options' => $artist_options,
        '#required' => FALSE,
        '#default_value' => variable_get('topspin_api_artist_id', ''),
      );
    }
    
    // Blocks.
    /**
     * This is disabled for the initial release of the module.
     * 
     * We want to utilise this in upcoming releases.
     * 
    $forms['general']['block'] = array(
      '#type' => 'fieldset',
      '#title' => t("Extra blocks"),
      //'#description' => t(''),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
    );
    $forms['general']['block']['topspin_store_custom_blocks'] = array(
      '#type' => 'checkbox',
      '#title' => t('Add more custom product blocks to your site?'),
      '#description' => t('Choose which offers you would like to be usable as a block. Once enabled, you must place the blocks at <a href="/admin/build/block">/admin/build/block</a>. You can also add/edit block titles.'),
      '#options' => array(
        0 => t('No'),
        1 => t('Yes'),
      ),
      '#default_value' => variable_get('topspin_store_custom_blocks', 0),
    );
    
    // Create an array by artists.
    // Show offers organized by artist.
    $artists_indexed = array_keys($artists);
    foreach ($artists as $artist_id => $offers) {
      foreach ($offers as $index => $offer) {
        if ($offer->offer_type != 'buy_button') {
          continue;
        }
        // Add artist fieldset if needed. We do it here so that we have easy access to the artist name.
        if (!isset($forms['general']['block'][$artist_id])) {
          $prefix = '';
          $suffix = '';
          $forms['general']['block'][$artist_id] = array('#type' => 'fieldset', '#title' => check_plain($offer->artist_name), '#collapsible' => TRUE, '#collapsed' => FALSE, '#prefix' => $prefix, '#suffix' => $suffix);
        }
        // Add all "block enable" checkboxes.
        $forms['general']['block'][$artist_id]['topspin_enabled_offer_block_'. $offer->id] = array(
          '#type' => 'checkbox',
          '#title' => check_plain($offer->name),
          '#default_value' => variable_get('topspin_enabled_offer_block_'. $offer->id, 0),
        );
      }
    }
     * 
     */
  }

  /**
   * As per D6 version, there is more scope to add extra clauses below
   * but currently we are looking at just the general block configuration
   */

  return $forms;
}